@@ -24,6 +24,14 @@
 #'    coefficient names, e.g. \code{rm.terms = "t_name [2,3]"} would remove the terms
 #'    \code{"t_name2"} and \code{"t_name3"} (assuming that the variable \code{t_name}
 #'    was categorical and has at least the factor levels \code{2} and \code{3}).
+#' @param keep,drop Character containing a regular expression pattern that
+#'   describes the parameters that should be included (for \code{keep}) or excluded
+#'   (for \code{drop}) in the returned data frame. \code{keep} may also be a
+#'   named list of regular expressions. All non-matching parameters will be
+#'   removed from the output. If \code{keep} has more than one element, these
+#'   will be merged with an \code{OR} operator into a regular expression pattern
+#'   like this: \code{"(one|two|three)"}. See further details in
+#'   \code{?parameters::model_parameters}.
 #' @param pred.labels Character vector with labels of predictor variables.
 #'    If not \code{NULL}, \code{pred.labels} will be used in the first
 #'    table column with the predictors' names. By default, if \code{auto.label = TRUE}
@@ -105,6 +113,7 @@
 #' @param emph.p Logical, if \code{TRUE}, significant p-values are shown bold faced.
 #' @param digits Amount of decimals for estimates
 #' @param digits.p Amount of decimals for p-values
+#' @param digits.rsq Amount of decimals for r-squared values
 #' @param digits.re Amount of decimals for random effects part of the summary table.
 #' @param collapse.ci Logical, if \code{FALSE}, the CI values are shown in
 #'    a separate table column.
@@ -221,15 +230,7 @@
 #'    }
 #' }
 #
-#' @importFrom dplyr full_join select if_else mutate
-#' @importFrom purrr reduce map2 map_if map_df compact map_lgl map_chr flatten_chr
-#' @importFrom sjlabelled response_labels term_labels
-#' @importFrom sjmisc word_wrap var_rename add_columns add_case
-#' @importFrom insight model_info is_multivariate find_random get_data find_predictors
-#' @importFrom performance r2 variance_decomposition
-#' @importFrom stats nobs setNames
 #' @importFrom rlang .data
-#' @importFrom utils packageVersion
 #' @export
 tab_model <- function(
   ...,
@@ -261,6 +262,8 @@ tab_model <- function(
   terms = NULL,
   rm.terms = NULL,
   order.terms = NULL,
+  keep = NULL,
+  drop = NULL,
 
   title = NULL,
   pred.labels = NULL,
@@ -273,7 +276,7 @@ tab_model <- function(
 
   robust = FALSE,
   vcov.fun = NULL,
-  vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5", "CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3"),
+  vcov.type = NULL,
   vcov.args = NULL,
 
   string.pred = "Predictors",
@@ -318,6 +321,7 @@ tab_model <- function(
 
   digits = 2,
   digits.p = 3,
+  digits.rsq = 3,
   digits.re = 2,
   emph.p = TRUE,
   p.val = NULL,
@@ -341,11 +345,10 @@ tab_model <- function(
   }
 
   if (!is.null(p.val)) {
-    p.val <- match.arg(p.val, choices = c("wald", "profile", "kenward", "kr", "satterthwaite", "ml1", "betwithin"))
+    p.val <- match.arg(p.val, choices = c("wald", "profile", "kenward", "kr", "satterthwaite", "ml1", "betwithin", "residual", "normal"))
   }
   p.style <- match.arg(p.style)
   prefix.labels <- match.arg(prefix.labels)
-  vcov.type <- match.arg(vcov.type)
 
   change_string_est <- !missing(string.est)
 
@@ -362,21 +365,16 @@ tab_model <- function(
 
   # default robust?
   if (isTRUE(robust)) {
-    vcov.type <- "HC3"
-    vcov.fun <- "vcovHC"
+    vcov.fun <- "HC3"
   }
 
-  # check se-argument
-  vcov.fun <- check_se_argument(se = vcov.fun, type = NULL)
-
-
   models <- list(...)
 
-  if (length(class(models[[1]])) == 1 && class(models[[1]]) == "list")
+  if (length(class(models[[1]])) == 1 && inherits(models[[1]], "list"))
     models <- lapply(models[[1]], function(x) x)
 
   names(models) <- unlist(lapply(
-    match.call(expand.dots = F)$`...`,
+    match.call(expand.dots = FALSE)$`...`,
     function(.x) deparse(.x, width.cutoff = 500L))
   )
 
@@ -435,7 +433,7 @@ tab_model <- function(
 
   model.list <- purrr::map2(
     models,
-    1:length(models),
+    seq_along(models),
     function(model, i) {
 
       # get info on model family
@@ -447,7 +445,7 @@ tab_model <- function(
       # check whether estimates should be transformed or not
 
       if (auto.transform) {
-        if (fam.info$is_linear)
+        if (fam.info$is_linear || identical(fam.info$link_function, "identity"))
           transform <- NULL
         else
           transform <- "exp"
@@ -468,7 +466,9 @@ tab_model <- function(
         bootstrap = bootstrap,
         iterations = iterations,
         seed = seed,
-        p_adjust = p.adjust
+        p_adjust = p.adjust,
+        keep = keep,
+        drop = drop
       )
 
 
@@ -530,7 +530,9 @@ tab_model <- function(
           standardize = std_method,
           bootstrap = bootstrap,
           iterations = iterations,
-          seed = seed
+          seed = seed,
+          keep = keep,
+          drop = drop
         ) %>%
           format_p_values(p.style, digits.p, emph.p, p.threshold) %>%
           sjmisc::var_rename(
@@ -750,12 +752,8 @@ tab_model <- function(
         # multiple computation
         if (is_mixed_model(model)) {
           if (inherits(model, "brmsfit")) {
-            rsqdummy <- tryCatch(
-              {
-                suppressWarnings(performance::r2(model))
-              },
-              error = function(x) { NULL }
-            )
+            rsqdummy <- tryCatch(suppressWarnings(performance::r2(model)),
+                                 error = function(x) NULL)
             if (!is.null(rsqdummy)) {
               rsq <- list(
                 `Marginal R2` = rsqdummy$R2_Bayes_marginal,
@@ -776,12 +774,8 @@ tab_model <- function(
             }
           }
         } else {
-          rsq <- tryCatch(
-            {
-              suppressWarnings(performance::r2(model))
-            },
-            error = function(x) { NULL }
-          )
+          rsq <- tryCatch(suppressWarnings(performance::r2(model)),
+                          error = function(x) NULL)
 
           # fix names of r-squared values
 
@@ -941,7 +935,7 @@ tab_model <- function(
         dv.labels <- sjmisc::word_wrap(dv.labels, wrap = wrap.labels, linesep = "<br>")
       }
 
-      model.data <- purrr::map2(model.data, 1:length(model.data), function(x, y) {
+      model.data <- purrr::map2(model.data, seq_along(model.data), function(x, y) {
         colnames(x) <- gsub(
           pattern = "_1",
           replacement = sprintf("_%i", y),
@@ -1041,7 +1035,7 @@ tab_model <- function(
       )
     } else {
       pred.labels <- NULL
-      for (pl_counter in 1:length(models)) {
+      for (pl_counter in seq_along(models)) {
         pred.labels <- c(pred.labels, parameters::format_parameters(models[[pl_counter]]))
       }
       pred.labels <- pred.labels[!duplicated(names(pred.labels))]
@@ -1082,7 +1076,7 @@ tab_model <- function(
       # some labels may not match. in this case, we only need to replace those
       # elements in the vector that match a specific label, but
       # at the correct position inside "dat$term"
-      tr <- 1:nrow(dat)
+      tr <- seq_len(nrow(dat))
       find.matches <- match(dat$term, names(pred.labels))
       find.na <- which(is.na(find.matches))
       if (!sjmisc::is_empty(find.na)) tr <- tr[-find.na]
@@ -1104,7 +1098,7 @@ tab_model <- function(
       # also label zero-inflated part
 
       if (!is.null(zeroinf)) {
-        tr <- 1:nrow(zeroinf)
+        tr <- seq_len(nrow(zeroinf))
         find.matches <- match(zeroinf$term, names(pred.labels))
         find.na <- which(is.na(find.matches))
         if (!sjmisc::is_empty(find.na)) tr <- tr[-find.na]
@@ -1150,7 +1144,7 @@ tab_model <- function(
     pos <- grep("^estimate_", x)
 
     if (!sjmisc::is_empty(pos)) {
-      i <- as.numeric(sub("estimate_", "", x = x, fixed = T))
+      i <- as.numeric(sub("estimate_", "", x = x, fixed = TRUE))
 
       if (insight::is_multivariate(models[[1]]))
         mr <- i
@@ -1263,6 +1257,7 @@ tab_model <- function(
     file = file,
     use.viewer = use.viewer,
     footnote = footnote,
+    digits.rsq = digits.rsq,
     digits.re = digits.re,
     encoding = encoding
   )
@@ -1307,7 +1302,18 @@ sort_columns <- function(x, is.stan, col.order) {
 
 
 #' @importFrom dplyr select slice
-remove_unwanted <- function(dat, show.intercept, show.est, show.std, show.ci, show.se, show.stat, show.p, show.df, show.response, terms, rm.terms) {
+remove_unwanted <- function(dat,
+                            show.intercept,
+                            show.est,
+                            show.std,
+                            show.ci,
+                            show.se,
+                            show.stat,
+                            show.p,
+                            show.df,
+                            show.response,
+                            terms,
+                            rm.terms) {
   if (!show.intercept) {
     ints1 <- string_contains("(Intercept", x = dat$term)
     ints2 <- string_contains("b_Intercept", x = dat$term)
@@ -1370,14 +1376,14 @@ remove_unwanted <- function(dat, show.intercept, show.est, show.std, show.ci, sh
 
   if (!is.null(terms)) {
     terms <- parse_terms(terms)
-    keep <- which(dat$term %in% terms)
-    dat <- dplyr::slice(dat, !! keep)
+    keep_terms <- which(dat$term %in% terms)
+    dat <- dplyr::slice(dat, !! keep_terms)
   }
 
   if (!is.null(rm.terms)) {
     rm.terms <- parse_terms(rm.terms)
-    keep <- which(!(dat$term %in% rm.terms))
-    dat <- dplyr::slice(dat, !! keep)
+    keep_terms <- which(!(dat$term %in% rm.terms))
+    dat <- dplyr::slice(dat, !! keep_terms)
   }
 
   dat
@@ -1413,7 +1419,7 @@ prepare.labels <- function(x, grp, categorical, models) {
   x
 }
 
-format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold){
+format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold) {
   # get stars and significance at alpha = 0.05 ----
 
   dat <- dat %>%
@@ -1438,9 +1444,9 @@ format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold){
   # indicate p <0.001 ----
 
   pv <- paste0("0.", paste(rep("0", digits.p), collapse = ""))
-  dat$p.value[dat$p.value == pv] <- "&lt;0.001"
+  dat$p.value[dat$p.value == pv] <- paste("&lt;", format(10^(-digits.p), scientific = FALSE), sep = "")
 
   pv <- paste0("<strong>0.", paste(rep("0", digits.p), collapse = ""), "</strong>")
-  dat$p.value[dat$p.value == pv] <- "<strong>&lt;0.001</strong>"
+  dat$p.value[dat$p.value == pv] <- paste("<strong>&lt;", format(10^(-digits.p), scientific = FALSE), "</strong>", sep = "")
   dat
 }
