@@ -43,7 +43,7 @@ axis_limits_and_ticks <- function(axis.lim, min.val, max.val, grid.breaks, expon
   if (is.infinite(max.val) || is.na(max.val)) max.val <- max.est
 
 
-  # for negative signes, need to change multiplier
+  # for negative signs, need to change multiplier
 
   if (min.val < 0) fac.ll <- 1 / fac.ll
   if (max.val < 0) fac.ul <- 1 / fac.ul
@@ -101,8 +101,6 @@ axis_limits_and_ticks <- function(axis.lim, min.val, max.val, grid.breaks, expon
 }
 
 
-#' @importFrom insight model_info
-#' @importFrom dplyr case_when
 estimate_axis_title <- function(fit, axis.title, type, transform = NULL, multi.resp = NULL, include.zeroinf = FALSE) {
 
   # no automatic title for effect-plots
@@ -122,10 +120,12 @@ estimate_axis_title <- function(fit, axis.title, type, transform = NULL, multi.r
       !is.null(transform) && transform == "plogis" ~ "Probabilities",
       is.null(transform) && fitfam$is_binomial ~ "Log-Odds",
       is.null(transform) && fitfam$is_ordinal ~ "Log-Odds",
+      is.null(transform) && fitfam$is_multinomial ~ "Log-Odds",
       is.null(transform) && fitfam$is_categorical ~ "Log-Odds",
       is.null(transform) && fitfam$is_count ~ "Log-Mean",
       fitfam$is_count ~ "Incidence Rate Ratios",
       fitfam$is_ordinal ~ "Odds Ratios",
+      fitfam$is_multinomial ~ "Odds Ratios",
       fitfam$is_categorical ~ "Odds Ratios",
       fitfam$is_binomial && !fitfam$is_logit ~ "Risk Ratios",
       fitfam$is_binomial ~ "Odds Ratios",
@@ -320,14 +320,9 @@ model_deviance <- function(x) {
 }
 
 
-#' @importFrom stats AIC
+#' @importFrom performance performance_aic
 model_aic <- function(x) {
-  tryCatch(
-    {
-      stats::AIC(x)
-    },
-    error = function(x) { NULL }
-  )
+  performance::performance_aic(x)
 }
 
 
@@ -353,10 +348,12 @@ model_loglik <- function(x) {
 }
 
 
-#' @importFrom lme4 getME
 #' @importFrom stats deviance
 m_deviance <- function(x) {
   if (is_merMod(x)) {
+    if (!requireNamespace("lme4", quietly = TRUE)) {
+      stop("Package 'lme4' required for this function to work, please install it.")
+    }
     d <- lme4::getME(x, "devcomp")$cmp["dev"]
     if (is.na(d)) d <- stats::deviance(x, REML = FALSE)
   } else {
@@ -384,10 +381,10 @@ tidy_label <- function(labs, sep = ".") {
 }
 
 
-#' @importFrom lme4 ranef
-#' @importFrom purrr map_df
-#' @importFrom insight find_random
 se_ranef <- function(object) {
+  if (!requireNamespace("lme4", quietly = TRUE)) {
+    stop("Package 'lme4' required for this function to work, please install it.")
+  }
   if (inherits(object, "MixMod")) {
     se.bygroup <- lme4::ranef(object, post_vars = TRUE)
     vars.m <- attr(se.bygroup, "post_vars")
@@ -429,7 +426,6 @@ se_ranef <- function(object) {
 }
 
 
-#' @importFrom insight n_obs
 get_observations <- function(model) {
   tryCatch(
     {
@@ -440,7 +436,6 @@ get_observations <- function(model) {
 }
 
 
-#' @importFrom insight find_predictors get_data
 .labelled_model_data <- function(models) {
   # to be generic, make sure argument is a list
   if (!inherits(models, "list")) models <- list(models)
