@@ -1,7 +1,28 @@
+params <-
+list(EVAL = FALSE)
+
 ## ----set-options, echo = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-knitr::opts_chunk$set(collapse = TRUE, comment = "#>", dev = "png", fig.width = 7, fig.height = 3.5, message = FALSE, warning = FALSE)
+knitr::opts_chunk$set(
+  collapse = TRUE, 
+  comment = "#>", 
+  message = FALSE,
+  dev = "png", 
+  fig.width = 7, 
+  fig.height = 3.5, 
+  warning = FALSE,
+  eval = TRUE
+  # eval = if (isTRUE(exists("params"))) params$EVAL else FALSE
+)
 options(width = 800, tibble.width = Inf)
 
+if (!requireNamespace("sjmisc", quietly = TRUE) ||
+    !requireNamespace("splines", quietly = TRUE) ||
+    !requireNamespace("ggplot2", quietly = TRUE) ||
+    !requireNamespace("sjlabelled", quietly = TRUE)) {
+  knitr::opts_chunk$set(eval = FALSE)
+}
+
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjPlot)
 library(ggplot2)
